# PySAP Macro

Python script to connect with SAP and allow usage of VB scripts

## Getting Started

These instructions will get you a copy of the project up and running on your local machine.

### Installing

To install this package and all of it's requirements, run the following code on your terminal:

```
pip install pysap_macro
```

## Testing if it is working

You can create a Python file for testing purpose with the following code:

```
asdasd
```

## Authors

Thanks to [Fkfouri's sapy_script](https://github.com/fkfouri/sapy_script) for creating an amazing library and providing it on Github. This project was created based on his code.

* **Mateus Lima Silva**

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
